@@ -1,12 +1,12 @@
-require 'fastercsv'
+require 'csv'
 
 module OutputToCSV
   def self.output_results( filename, results )
-    FasterCSV.open( filename, 'w' ) do |csv|
+    CSV.open( filename, 'w' ) do |csv|
       # Iterate over each result set, which contains many results
       results.each do |result_set|
         columns, times = [], []
-        result_set.each do |result| 
+        result_set.each do |result|
           columns << result.description
           times << result.tms.real
         end
