@@ -236,7 +236,7 @@ class ActiveRecord::Base
     # This returns an object which responds to +failed_instances+ and +num_inserts+.
     # * failed_instances - an array of objects that fails validation and were not committed to the database. An empty array if no validation is performed.
     # * num_inserts - the number of insert statements it took to import the data
-    # * ids - the priamry keys of the imported ids, if the adpater supports it, otherwise and empty array.
+    # * ids - the primary keys of the imported ids, if the adpater supports it, otherwise and empty array.
     def import(*args)
       if args.first.is_a?( Array ) and args.first.first.is_a? ActiveRecord::Base
         options = {}
@@ -253,6 +253,11 @@ class ActiveRecord::Base
       options = { :validate=>true, :timestamps=>true, :primary_key=>primary_key }
       options.merge!( args.pop ) if args.last.is_a? Hash
 
+      # Don't modify incoming arguments
+      if options[:on_duplicate_key_update]
+        options[:on_duplicate_key_update] = options[:on_duplicate_key_update].dup
+      end
+
       is_validating = options[:validate]
       is_validating = true unless options[:validate_with_context].nil?
 
@@ -285,6 +290,7 @@ class ActiveRecord::Base
       end
 
       # dup the passed in array so we don't modify it unintentionally
+      column_names = column_names.dup
       array_of_attributes = array_of_attributes.dup
 
       # Force the primary key col into the insert if it's not
@@ -349,6 +355,7 @@ class ActiveRecord::Base
         instance = new do |model|
           hsh.each_pair{ |k,v| model.send("#{k}=", v) }
         end
+
         if not instance.valid?(options[:validate_with_context])
           array_of_attributes[ i ] = nil
           failed_instances << instance
@@ -376,8 +383,13 @@ class ActiveRecord::Base
 
       unless scope_columns.blank?
         scope_columns.zip(scope_values).each do |name, value|
-          next if column_names.include?(name.to_sym)
-          column_names << name.to_sym
+          name_as_sym = name.to_sym
+          next if column_names.include?(name_as_sym)
+
+          is_sti = (name_as_sym == inheritance_column.to_sym && self < base_class)
+          value = value.first if is_sti
+
+          column_names << name_as_sym
           array_of_attributes.each { |attrs| attrs << value }
         end
       end
@@ -417,8 +429,14 @@ class ActiveRecord::Base
     def set_ids_and_mark_clean(models, import_result)
       unless models.nil?
         import_result.ids.each_with_index do |id, index|
-          models[index].id = id.to_i
-          models[index].instance_variable_get(:@changed_attributes).clear # mark the model as saved
+          model = models[index]
+          model.id = id.to_i
+          if model.respond_to?(:clear_changes_information) # Rails 4.0 and higher
+            model.clear_changes_information
+          else  # Rails 3.1
+            model.instance_variable_get(:@changed_attributes).clear
+          end
+          model.instance_variable_set(:@new_record, false)
         end
       end
     end
@@ -473,10 +491,12 @@ class ActiveRecord::Base
           if val.nil? && column.name == primary_key && !sequence_name.blank?
              connection_memo.next_value_for_sequence(sequence_name)
           elsif column
-            if column.respond_to?(:type_cast_from_user)                         # Rails 4.2 and higher
+            if respond_to?(:type_caster) && type_caster.respond_to?(:type_cast_for_database) # Rails 5.0 and higher
+              connection_memo.quote(type_caster.type_cast_for_database(column.name, val))
+            elsif column.respond_to?(:type_cast_from_user)                      # Rails 4.2 and higher
               connection_memo.quote(column.type_cast_from_user(val), column)
-            else
-              connection_memo.quote(column.type_cast(val), column)              # Rails 3.1, 3.2, and 4.1
+            else                                                                # Rails 3.1, 3.2, and 4.1
+              connection_memo.quote(column.type_cast(val), column)
             end
           end
         end
@@ -509,7 +529,7 @@ class ActiveRecord::Base
             array_of_attributes.each { |arr| arr << value }
           end
 
-          if supports_on_duplicate_key_update?
+          if supports_on_duplicate_key_update? and options[:on_duplicate_key_update] != false
             if options[:on_duplicate_key_update]
               options[:on_duplicate_key_update] << key.to_sym if options[:on_duplicate_key_update].is_a?(Array) && !options[:on_duplicate_key_update].include?(key.to_sym)
               options[:on_duplicate_key_update][key.to_sym] = key.to_sym if options[:on_duplicate_key_update].is_a?(Hash)
