@@ -1,7 +1,7 @@
 # encoding: UTF-8
 def should_support_mysql_import_functionality
   # Forcefully disable strict mode for this session.
-  ActiveRecord::Base.connection.execute "set sql_mode=''"
+  ActiveRecord::Base.connection.execute "set sql_mode='STRICT_ALL_TABLES'"
 
   describe "#import with :on_duplicate_key_update option (mysql specific functionality)" do
     extend ActiveSupport::TestCase::MySQLAssertions
@@ -16,6 +16,15 @@ def should_support_mysql_import_functionality
     macro(:perform_import){ raise "supply your own #perform_import in a context below" }
     macro(:updated_topic){ Topic.find(@topic.id) }
 
+    describe "argument safety" do
+      it "should not modify the passed in :on_duplicate_key_update columns array" do
+        assert_nothing_raised do
+          columns = %w(title author_name).freeze
+          Topic.import columns, [["foo", "bar"]], :on_duplicate_key_update => columns
+        end
+      end
+    end
+
     context "given columns and values with :validation checks turned off" do
       let(:columns){  %w( id title author_name author_email_address parent_id ) }
       let(:values){ [ [ 99, "Book", "John Doe", "john@doe.com", 17 ] ] }
@@ -116,13 +125,33 @@ def should_support_mysql_import_functionality
         should_update_fields_mentioned_with_hash_mappings
       end
     end
+  
+    context "given array of model instances with :on_duplicate_key_update turned off" do
+      let(:columns){  %w( id title author_name author_email_address parent_id ) }
+      let(:values){ [ [ 100, "Book", "John Doe", "john@doe.com", 17 ] ] }
+      let(:updated_values){ [ [ 100, "Book - 2nd Edition", "This should raise an exception", "john@nogo.com", 57 ] ] }
 
+      macro(:perform_import) do |*opts|
+        # `:on_duplicate_key_update => false` is the tested feature
+        Topic.import columns, updated_values, opts.extract_options!.merge(:on_duplicate_key_update => false, :validate => false)
+      end
+
+      setup do
+        Topic.import columns, values, :validate => false
+        @topic = Topic.find 100
+      end
+    
+      context "using string column names" do
+        let(:update_columns){ [ "title", "author_email_address", "parent_id" ] }
+        should_raise_update_fields_mentioned
+      end
+    end
   end
 
   describe "#import with :synchronization option" do
     let(:topics){ Array.new }
-    let(:values){ [ [topics.first.id, "Jerry Carter"], [topics.last.id, "Chad Fowler"] ]}
-    let(:columns){ %W(id author_name) }
+    let(:values){ [ [topics.first.id, "Jerry Carter", "title1"], [topics.last.id, "Chad Fowler", "title2"] ]}
+    let(:columns){ %W(id author_name title) }
 
     setup do
       topics << Topic.create!(:title=>"LDAP", :author_name=>"Big Bird")
