@@ -7,12 +7,12 @@ function run {
   $@
 }
 
-for activerecord_version in "3.1" "3.2" "4.1" "4.2" ; do
+for activerecord_version in "3.1" "3.2" "4.0" "4.1" "4.2" "5.0" ; do
   export AR_VERSION=$activerecord_version
 
   bundle update activerecord
 
-  run run bundle exec rake test:em_mysql2               # Run tests for em_mysql2
+  run bundle exec rake test:em_mysql2               # Run tests for em_mysql2
   run bundle exec rake test:mysql                   # Run tests for mysql
   run bundle exec rake test:mysql2                  # Run tests for mysql2
   run bundle exec rake test:mysql2spatial           # Run tests for mysql2spatial
